# The Restless Dungeon

A Text-based dungeon adventure game.

## Installation

Clone the repo and install required dependencies:

```bash
pip install restless-dungeon
```

## Updates

```bash
pip install --upgrade restless-dungeon
```

## Usage

Run the program:

```bash
restless-dungeon
```


### AI Usage

I used AI (GitHub Copilot and ChatGPT) for coming up with the name for the game, writing a couple of the commit messages, and helping with debugging when my eyes couldn't find the problems. ChatGPT also helped me upload the project to PyPI.
